Name:           fftw
Version:        3.2.2
Release:        3%{?dist}
Summary:        Fast Fourier Transform library
Group:          System Environment/Libraries
License:        GPLv2+
URL:            http://www.fftw.org/
Source0:        http://www.fftw.org/fftw-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

%if 0%{?rhel} == 4
BuildRequires:  gcc-g77
%else
BuildRequires:  gcc-gfortran
%endif
# For check phase
BuildRequires: time perl

Requires(post): info 
Requires(preun): info

%description
FFTW is a C subroutine library for computing the Discrete Fourier
Transform (DFT) in one or more dimensions, of both real and complex
data, and of arbitrary input size.

# For RPMForge compatibility - the fftw package was in RPMForge before Fedora
# EPEL was started, and is of version 2, which is API incompatible with the 3
# series.

%package -n fftw3
Summary:        Fast Fourier Transform library
Group:          System Environment/Libraries
Provides:       fftw = %{version}-%{release}

%description -n fftw3
FFTW is a C subroutine library for computing the Discrete Fourier
Transform (DFT) in one or more dimensions, of both real and complex
data, and of arbitrary input size.


%package -n fftw3-devel
Summary:        Headers, libraries and docs for the FFTW library
Group:          Development/Libraries
Requires:       fftw3 = %{version}-%{release} pkgconfig
Requires:       pkgconfig
Provides:       fftw-devel = %{version}-%{release}

%description -n fftw3-devel
FFTW is a C subroutine library for computing the Discrete Fourier
Transform (DFT) in one or more dimensions, of both real and complex
data, and of arbitrary input size.

This package contains header files and development libraries needed to
develop programs using the FFTW fast Fourier transform library.


%package -n fftw3-static
Summary:        Static version of the FFTW library
Group:          Development/Libraries
Requires:       %{name}-devel = %{version}-%{release}
Provides:       fftw-static = %{version}-%{release}

%description -n fftw3-static
The fftw-static package contains the statically linkable version of
the FFTW fast Fourier transform library.


%prep
%setup -q -c %{name}-%{version}
for dir in single double long; do
  cp -a fftw-%{version} $dir
done
rm -rf fftw-%{version}


%build
# Set Fortran compiler to be used
%if 0%{?rhel} == 4
export F77=g77
%else
export F77=gfortran
%endif

CONFIG_FLAGS="--enable-shared --disable-dependency-tracking --enable-threads"
pushd double
        %configure $CONFIG_FLAGS
        sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
        sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
        make %{?_smp_mflags}
popd
pushd single
        %configure $CONFIG_FLAGS --enable-single
        sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
        sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
        make %{?_smp_mflags}
popd
pushd long
        %configure $CONFIG_FLAGS --enable-long-double
        sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
        sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
        make %{?_smp_mflags}
popd


%install
rm -rf ${RPM_BUILD_ROOT}
pushd double
        make install DESTDIR=${RPM_BUILD_ROOT}
        cp -a AUTHORS COPYING COPYRIGHT ChangeLog NEWS README* TODO ../
        cp -a doc/ ../
popd
pushd single
        make install DESTDIR=${RPM_BUILD_ROOT}
popd
pushd long
        make install DESTDIR=${RPM_BUILD_ROOT}
popd
rm -f ${RPM_BUILD_ROOT}%{_infodir}/dir
rm -f ${RPM_BUILD_ROOT}%{_libdir}/*.la

%clean
rm -rf ${RPM_BUILD_ROOT}

%check
bdir=`pwd`
export LD_LIBRARY_PATH=$bdir/single/.libs:$bdir/single/threads/.libs:$bdir/double/.libs:$bdir/double/threads/.libs:$bdir/long/.libs:$bdir/long/threads/.libs
make -C single check
make -C double check
make -C long check

%post -n fftw3 -p /sbin/ldconfig
%postun -n fftw3 -p /sbin/ldconfig

%post -n fftw3-devel
/sbin/install-info --section="Math" %{_infodir}/%{name}.info.gz %{_infodir}/dir  2>/dev/null || :

%preun -n fftw3-devel
if [ "$1" = 0 ]; then
  /sbin/install-info --delete %{_infodir}/%{name}.info.gz %{_infodir}/dir 2>/dev/null || :
fi

%files -n fftw3
%defattr(-,root,root,-)
%doc AUTHORS COPYING COPYRIGHT ChangeLog NEWS README* TODO
%doc %{_mandir}/man1/fftw*.1.*
%{_bindir}/fftw*-wisdom*
%{_libdir}/libfftw3*.so.*

%files -n fftw3-devel
%defattr(-,root,root,-)
%doc doc/*.pdf doc/html/* doc/FAQ/fftw-faq.html/
%doc %{_infodir}/fftw3.info*
%{_includedir}/fftw3.*
%{_libdir}/pkgconfig/fftw3*.pc
%{_libdir}/libfftw3*.so

%files -n fftw3-static
%defattr(-,root,root,-)
%{_libdir}/libfftw3*.a


%changelog
* Fri Jan 8 2010 Jussi Lehtola <jussilehtola@fedoraproject.org> 3.2.2-3
- Same thing, but without changing Name tag to fftw3.

* Fri Jan 8 2010 Jussi Lehtola <jussilehtola@fedoraproject.org> 3.2.2-2
- Revert package name change due to RPMForge compatibility (fftw is version 2
  series in RPMForge).

* Fri Jan 1 2010 Jussi Lehtola <jussilehtola@fedoraproject.org> 3.2.2-1
- Update to 3.2.2 from rawhide tree.
- Change name of package to fftw(-devel) to conform with Package Naming
  Guidelines.

* Wed Jun 25 2008 Rex Dieter <rdieter@fedoraproject.org> 3.1.2-5.1
- re-enable %%check
- License: GPLv2+

* Thu Jul 12 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 3.1.2-5
- fftw3(-devel): Provides: fftw(-devel) = %%version ...
- cleanup, +%%check section (disabled by default)

* Tue Jul 10 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 3.1.2-4
- (re)name -> fftw3 (epel-only, for rpmforge compatibility, #246004)

* Thu Oct 05 2006 Christian Iseli <Christian.Iseli@licr.org> 3.1.2-3
- rebuilt for unwind info generation, broken in gcc-4.1.1-21

* Tue Sep 26 2006 Quentin Spencer <qspencer@users.sf.net> 3.1.2-2
- BuildRequires: pkgconfig for -devel (bug 206444).

* Fri Sep  8 2006 Quentin Spencer <qspencer@users.sf.net> 3.1.2-1
- New release.

* Fri Jun  2 2006 Quentin Spencer <qspencer@users.sf.net> 3.1.1-1
- New upstream release.

* Fri Feb 24 2006 Quentin Spencer <qspencer@users.sf.net> 3.1-4
- Re-enable static libs (bug 181897).
- Build long-double version of libraries (bug 182587).

* Mon Feb 13 2006 Quentin Spencer <qspencer@users.sf.net> 3.1-3
- Add Obsoletes and Provides.

* Mon Feb 13 2006 Quentin Spencer <qspencer@users.sf.net> 3.1-2
- Rebuild for Fedora Extras 5.
- Disable static libs.
- Remove obsolete configure options.

* Wed Feb  1 2006 Quentin Spencer <qspencer@users.sf.net> 3.1-1
- Upgrade to the 3.x branch, incorporating changes from the fftw3 spec file.
- Add dist tag.

* Mon May 23 2005 Michael Schwendt <mschwendt[AT]users.sf.net> - 2.1.5-8
- BuildReq gcc-gfortran (#156490).

* Sun May 22 2005 Jeremy Katz <katzj@redhat.com> - 2.1.5-7
- rebuild on all arches
- buildrequire compat-gcc-32-g77

* Fri Apr  7 2005 Michael Schwendt <mschwendt[AT]users.sf.net>
- rebuilt

* Wed Nov 10 2004 Matthias Saou <http://freshrpms.net/> 2.1.5-5
- Bump release to provide Extras upgrade path.

* Tue Apr 06 2004 Phillip Compton <pcompton[AT]proteinmedia.com> - 0:2.1.5-0.fdr.4
- BuildReq gcc-g77.

* Mon Sep 22 2003 Phillip Compton <pcompton[AT]proteinmedia.com> - 0:2.1.5-0.fdr.3
- Dropped post/preun scripts for info.

* Wed Sep 17 2003 Phillip Compton <pcompton[AT]proteinmedia.com> - 0:2.1.5-0.fdr.2
- Remove aesthetic comments.
- buildroot -> RPM_BUILD_ROOT.
- post/preun for info files.

* Mon Apr 07 2003 Phillip Compton <pcompton[AT]proteinmedia.com> - 0:2.1.5-0.fdr.1
- Updated to 2.1.5.

* Tue Apr 01 2003 Phillip Compton <pcompton[AT]proteinmedia.com> - 0:2.1.4-0.fdr.2
- Added Epoch:0.
- Added ldconfig to post and postun.

* Sun Mar 22 2003 Phillip Compton <pcompton[AT]proteinmedia.com> - 2.1.4-0.fdr.1
- Updated to 2.1.4.

* Fri Mar 14 2003 Phillip Compton <pcompton[AT]proteinmedia.com> - 2.1.3-0.fdr.1
- Fedorafied.

* Mon Oct 21 2002 Matthias Saou <matthias.saou@est.une.marmotte.net>
- Initial RPM release.

